package HTML::FormFu::DBIC;
use strict;
use warnings;

BEGIN {
    use Exporter ();
    use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
    $VERSION     = '0.01';
    @ISA         = qw(Exporter);
    #Give a hoot don't pollute, do not export more than needed by default
    @EXPORT      = qw();
    @EXPORT_OK   = qw(fill_formfu_values);
    %EXPORT_TAGS = ();
}

use Carp qw( croak );


sub fill_formfu_values {
    my ( $dbic, $form, $attrs ) = @_;

    $attrs = {
        prefix_col => '',
        suffix_col => '',
        %{$attrs || {}}
    };
    my $prefix = $attrs->{prefix_col};
    my $suffix = $attrs->{suffix_col};
    
    my $fields;
    eval {
        $fields = $form->get_fields;
    };
    croak "require a compatible form object: $@" if $@;
    
    for my $field (@$fields) {
        my $field_name = $field->name;
        next unless defined $field_name;

        my ($dbic_name) = ( $field_name =~ /\A(?:$prefix)?(.*)(?:$suffix)?\z/ );
        next unless $dbic->can( $dbic_name );
        my $value_field = $field->value_field || 'id';
        if ( ref $dbic->$dbic_name && $dbic->$dbic_name->can('id') && $dbic->$dbic_name->id ) {
            $field->default( $dbic->$dbic_name->id );
        } elsif ( $dbic->$dbic_name->isa( 'DBIx::Class::ResultSet' ) ) {
            my $presentation = $field->presentation || 'id';
            my @options = map { $_->$value_field } $dbic->$dbic_name;
#             while ( my $row = $dbic->$dbic_name->search()->next ){
#                 push @options, [ $row->$value_field, $row->$presentation ];
#             }
            $field->default( \@options );
        }
                else {
            $field->default( $dbic->$dbic_name );
                }
    }
    
    return $form;
}


#################### subroutine header begin ####################

=head2 sample_function

 Usage     : How to use this function/method
 Purpose   : What it does
 Returns   : What it returns
 Argument  : What it wants to know
 Throws    : Exceptions and other anomolies
 Comment   : This is a sample subroutine header.
           : It is polite to include more pod and fewer comments.

See Also   : 

=cut

#################### subroutine header end ####################


sub new
{
    my ($class, %parameters) = @_;

    my $self = bless ({}, ref ($class) || $class);

    return $self;
}


#################### main pod documentation begin ###################
## Below is the stub of documentation for your module. 
## You better edit it!


=head1 NAME

HTML::FormFu::DBIC - Module abstract (<= 44 characters) goes here

=head1 SYNOPSIS

  use HTML::FormFu::DBIC;
  blah blah blah


=head1 DESCRIPTION

Stub documentation for this module was created by ExtUtils::ModuleMaker.
It looks like the author of the extension was negligent enough
to leave the stub unedited.

Blah blah blah.


=head1 USAGE



=head1 BUGS



=head1 SUPPORT



=head1 AUTHOR

    HASH(0x617290)
    CPAN ID: MODAUTHOR
    XYZ Corp.
    a.u.thor@a.galaxy.far.far.away
    http://a.galaxy.far.far.away/modules

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1).

=cut

#################### main pod documentation end ###################


1;
# The preceding line will help the module return a true value

